This package contains implementations of subspace estimation and tracking techniques, with a focus on those techniques that are compatible with missing data.

Currently implemented are:
* GROUSE
* PETRELS

